@@ -40,7 +40,7 @@ class QueryRequestWriter(MessageWriter):
                  query_name,
                  query_parameters,
                  custom=False,
-                 query=None,
+                 cypher=None,
                  write_transaction=False,
                  split_results=False,
                  publish_to=None,
@@ -55,7 +55,7 @@ class QueryRequestWriter(MessageWriter):
         self.query_name = query_name
         self.query_parameters = query_parameters
         self.custom = custom
-        self.query = query
+        self.cypher = cypher
         self.write_transaction = write_transaction
         self.split_results = split_results
         self.publish_to = publish_to
@@ -75,7 +75,7 @@ class QueryRequestWriter(MessageWriter):
 
         if self.custom:
             custom_fields = {
-                "query": self.query,
+                "cypher": self.cypher,
                 "writeTransaction": self.write_transaction,
                 "splitResults": self.split_results,
                 "publishTo": self.publish_to,
@@ -223,6 +223,19 @@ class QueryResponseWriter(MessageWriter):
         return node_dict
 
 
+class JobCreatedWriter(MessageWriter):
+    def __init__(
+                 self,
+                 *,
+                 sender,
+                 seed_id,
+                 previous_event_id):
+
+        self.message_kind = "jobCreated"
+
+    def format_json_message(self):
+        pass
+
 class MessageReader(object):
 
     def __init__(
@@ -275,7 +288,7 @@ class QueryRequestReader(MessageReader):
 
         # Should only be populated for custom queries
         if self.custom:
-            self.query = self.body['query']
+            self.cypher = self.body['cypher']
             self.write_transaction = bool(self.body['writeTransaction'])
             self.split_results = bool(self.body['splitResults'])
             self.publish_to = self.body.get('publishTo')
@@ -300,6 +313,9 @@ class QueryResponseReader(MessageReader):
         self.relationships = self.body['relationships']
 
 
+class JobCreatedReader(MessageReader):
+    pass
+
 
 """
 class JobLauncherResponse(TrellisMessage):
